@@ -1,10 +1,10 @@
 # @package      hubzero-mysql
 # @file         hubzero-fix-debian-maint.sql
 # @author       Nicholas J. Kisseberth <nkissebe@purdue.edu>
-# @copyright    Copyright (c) 2010-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2010-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2010-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2010-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,8 +25,7 @@
 # HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 
-UPDATE `user` SET `Create_view_priv`='Y',`Show_view_priv`='Y',`Create_routine_priv`='Y',
-`Alter_routine_priv`='Y',`Create_user_priv`='Y' WHERE User='debian-sys-maint';
+UPDATE `user` SET `Create_view_priv`='Y',`Show_view_priv`='Y',`Create_routine_priv`='Y',`Alter_routine_priv`='Y',`Create_user_priv`='Y' WHERE User='debian-sys-maint';
 
 FLUSH PRIVILEGES;
 
